@@ -1,4 +1,5 @@
 # Setting global variables to avoid R CMD check notices
 utils::globalVariables(c('average', 'trend', 'year','Year', 'J-D', 'gmsl', 'method', 'month', 'name',
                          'age_ice', 'co2', 'land_use_change_co2', 'temp', 'value', 'size', 'measure','RevisedMajorHurricanes', 'RevisedACE',
-                         'cumco2', 'country'))
+                         'cumco2', 'country', 'data1', 'data366', 'day_of_year', 'dummy_date', 'linew', 'mean_temp', 'temp_anom',
+                         'hurr_type', 'ice_region'))
