@@ -48,15 +48,19 @@
 
 get_icecurves <- function(pole='N', measure='extent', use_cache = TRUE, write_cache = getOption("hs_write_cache")) {
 
-  if (pole!='S' & pole!='N') stop("pole must be 'N' or 'S'")
-    if (measure!='extent' & measure!='area') stop("measure must be 'extent' or 'area'")
+  if (pole != 'S' & pole != 'N') stop("pole must be 'N' or 'S'")
+    if (measure != 'extent' & measure != 'area') stop("measure must be 'extent' or 'area'")
 
   hs_path <- tools::R_user_dir("hockeystick","cache")
 
   if (use_cache) {
-    message('Please set use_cache=FALSE if you are changing pole or measure from last cached data.')
-    if (file.exists(file.path(hs_path,'icecurves.rds'))) return(invisible(readRDS((file.path(hs_path,'icecurves.rds')))))
-    }
+    if (file.exists(file.path(hs_path, 'icecurves.rds')))
+
+      {cached_ice <- readRDS((file.path(hs_path,'icecurves.rds')))
+       cached_type <- attr(cached_ice, 'hs_ice_type')
+
+      if (all(c(pole, measure) == cached_type)) return(invisible(cached_ice)) }
+  }
 
   connected <- .isConnected('ftp://sidads.colorado.edu/DATASETS/NOAA/G02135/north/monthly/data/')
   if (!connected) {message("Retrieving remote data requires internet connectivity."); return(invisible(NULL))}
@@ -64,8 +68,6 @@ get_icecurves <- function(pole='N', measure='extent', use_cache = TRUE, write_ca
   if (pole=='N') file_url <- 'ftp://sidads.colorado.edu/DATASETS/NOAA/G02135/north/monthly/data/'
   if (pole=='S') file_url <- 'ftp://sidads.colorado.edu/DATASETS/NOAA/G02135/south/monthly/data/'
 
-  if (file.exists(file.path(hscache_path(), 'icecurves.rds'))) file.remove(file.path(hscache_path(), 'icecurves.rds'))
-
   month <- c('01', '02', '03', '04', '05', '06', '07', '08', '09', '10', '11', '12')
 
   curve <- function(month) {
@@ -84,6 +86,8 @@ get_icecurves <- function(pole='N', measure='extent', use_cache = TRUE, write_ca
   icecurves <- do.call("rbind", icecurves)
   icecurves <- tibble::tibble(icecurves)
 
+    attr(icecurves, "hs_ice_type") <- c(pole, measure)
+
     if (write_cache) saveRDS(icecurves, file.path(hs_path, 'icecurves.rds'))
 
   invisible(icecurves) }
@@ -96,7 +100,6 @@ get_icecurves <- function(pole='N', measure='extent', use_cache = TRUE, write_ca
 #' @name plot_icecurves
 #' @param dataset Name of the tibble generated by `get_icecurves`, defaults to calling `get_icecurves`
 #' @param print (boolean) Display sea ice ggplot2 chart, defaults to TRUE. Use FALSE to not display chart.
-#' @param region Used in chart title, defaults to "Arctic"
 #' @return Invisibly returns a ggplot2 object with Sea Ice Index chart
 #'
 #' @details `plot_icecurves` invisibly returns a ggplot2 object with a pre-defined Sea Ice Index chart using data from `get_icecurves`.
@@ -123,29 +126,33 @@ get_icecurves <- function(pole='N', measure='extent', use_cache = TRUE, write_ca
 #'
 #' @export
 
-plot_icecurves <- function(dataset = get_icecurves(), region='Arctic', print=TRUE) {
+plot_icecurves <- function(dataset = get_icecurves(), print = TRUE) {
 
   if (is.null(dataset)) return(invisible(NULL))
 
   measure_name <- colnames(dataset)[3]
   measure_name <- paste(toupper(substr(measure_name, 1, 1)), substr(measure_name, 2, nchar(measure_name)), sep="")
-  title <- paste0(region, " Sea Ice ", measure_name," by Year and Month")
+
+  ice_region <- if (attr(dataset, "hs_ice_type")[1] == 'S') 'Antarctic' else 'Arctic'
+
+  title <- paste0(ice_region, ' Sea Ice ', measure_name, ' by Year and Month')
 
   colnames(dataset) <- c('year', 'month', 'measure')
   current_year <- max(dataset$year)
-  dataset$size <- ifelse(dataset$year == current_year, current_year, 'Previous')
+  dataset$linew <- ifelse(dataset$year == current_year, current_year, 'Previous')
   dataset <- dataset[dataset[,3] != '-9999', ]
 
-  plot <- ggplot(dataset, aes(x=month, y=measure, alpha=as.factor(size), size=as.factor(size), color=as.factor(year))) +
+  plot <- ggplot(dataset, aes(x=month, y=measure, alpha=as.factor(linew), linewidth=as.factor(linew), color=as.factor(year))) +
     geom_line() +scale_y_continuous(limits=c(0, 20)) +theme_bw() +
     scale_x_continuous(breaks = seq(1, 12, 1), minor_breaks = NULL) +
     scale_color_manual(guide = 'none', values = c(rep('darkgrey', length(unique(dataset$year))-1), 'dodgerblue')) +
-    scale_size_manual(labels = c(paste0('1979-', current_year-1), current_year), values = c(0.7, 2), breaks = c('Previous',as.character(current_year))) +
-    labs(title = title, x = 'Month', size = '', y=expression("Million km"^2),
-         caption='Source: National Snow & Ice Data Center\nhttps://nsidc.org/data/seaice_index') +
-    theme(legend.position = c(0.41, 0.92), legend.background = element_blank()) +
-    scale_alpha_manual(guide = 'none', labels = c('Previous', as.character(current_year)), values = c(0.4, 1), breaks = c('Previous', '2020')) +
-    guides(size = guide_legend(override.aes=list(colour=c('darkgrey', "dodgerblue"))))
+    scale_linewidth_manual(labels = c(paste0('1979-', current_year-1), current_year), values = c(0.7, 2), breaks = c('Previous', as.character(current_year))) +
+    labs(title = title, x = 'Month', y = expression("Million km"^2),
+         caption = 'Source: National Snow & Ice Data Center\nhttps://nsidc.org/data/seaice_index',
+         linewidth = NULL) +
+    theme(legend.position = c(0.41, 0.91), legend.background = element_blank()) +
+    scale_alpha_manual(guide = 'none', labels = c('Previous', as.character(current_year)), values = c(0.4, 1), breaks = c('Previous', '2023')) +
+    guides(linewidth = guide_legend(override.aes=list(color = c('darkgrey', "dodgerblue"))))
 
 
   if (print) suppressMessages( print(plot) )
